package live_logic

import (
	pbCommon "dcg/game/pb/common"
	pbMq "dcg/game/pb/mq"
	"dcg/pkg/cmd"
)

type (
	LiveLogic interface {
		SetGameType(gameType string)
		GameType() string

		SetCmdParser(parser *cmd.Parser)
		RegisterCMDHandler(h CMDHandlerFunc, cmd string, alias ...string)
		RegisterGiftHandler(h GiftHandler)
		RegisterNobilityHandler(h NobilityHandlerFunc)

		HandleDanmaku(liveRoom *LiveRoom, user *pbCommon.PbUser, dm *pbMq.MqDanmaku)
		HandleGift(liveRoom *LiveRoom, user *pbCommon.PbUser, gift *pbMq.MqGift)
		HandleNobility(liveRoom *LiveRoom, user *pbCommon.PbUser, msg *pbMq.MqNobilityBuy)
	}
	// LiveRoom 直播间定位
	LiveRoom struct {
		RoomId   int64
		Platform string
	}

	CMDHandlerFunc  func(liveRoom *LiveRoom, prefix string, content []rune, user *pbCommon.PbUser)
	GiftHandlerFunc func(liveRoom *LiveRoom, user *pbCommon.PbUser, gift *pbMq.MqGift)
	GiftHandler     func(next GiftHandlerFunc) GiftHandlerFunc

	NobilityHandlerFunc func(liveRoom *LiveRoom, user *pbCommon.PbUser, nobility *pbMq.MqNobilityBuy)
	// GiftLogic LiveLogic内部礼物逻辑处理
	GiftLogic struct {
		GiftIds []int64
		Fn      GiftLogicFunc
	}
	GiftLogicFunc func(liveRoom *LiveRoom, user *pbCommon.PbUser, gift *pbMq.MqGift)
)

var EmptyGiftHandlerFunc GiftHandlerFunc = func(liveRoom *LiveRoom, user *pbCommon.PbUser, gift *pbMq.MqGift) {}
